documentFactory.BaseDocumentStream

|  | ## Cheshire3 Object Model: Class BaseDocumentStream

Module documentFactory :: Class BaseDocumentStream

## Class BaseDocumentStream
source code

Known Subclasses:
  ClusterDocumentStream, ComponentDocumentStream, MultipleDocumentStream, RemoteDocumentStream, MarcDocumentStream, TermHashDocumentStream, XmlDocumentStream, postgres.PostgresDocumentStream, textmining.tmDocumentFactory.EnjuRecordDocumentStream

Instance Methods

__init__(self, session, stream, format, schema=None, codec=None, factory=None)
fetch_document(self, idx)
open_stream(self, stream)

Class Variables

codec |
documents |
factory |
filterRe |
format |
length |
locations |
schema |
stream |
streamLocation |

Method Details

### __init__(self, session, stream, format, schema=None, codec=None, factory=None) (Constructor) | source code

### fetch_document(self, idx) | source code

### open_stream(self, stream) | source code

Class Variable Details

    ### codec Value:
        ''

    ### documents Value:
        []

    ### factory Value:
        None

    ### filterRe Value:
        None

    ### format Value:
        ''

    ### length Value:
        0

    ### locations Value:
        []

    ### schema Value:
        ''

    ### stream Value:
        None

    ### streamLocation Value:
        ''